/*
 * Copyright (c) 2015 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <dlog.h>
#include <efl_extension.h>
#include <media_content.h>
#include <app_common.h>
#include "data.h"
#include "log.h"

/*
 * @brief: Initialize the data component
 */
void data_initialize(void)
{
	/*
	 * If you need to initialize managing data,
	 * please use this function.
	 */
}

/*
 * @brief: Finalize the data component
 */
void data_finalize(void)
{
	/*
	 * If you need to finalize managing data,
	 * please use this function.
	 */
}

/*
 * @brief: Get path of resource.
 * @param[file_in]: File name
 * @param[file_path_out]: The point to which save full path of the resource
 * @param[file_path_max]: Size of file name include path
 */
void data_get_resource_path(const char *file_in, char *file_path_out, int file_path_max)
{
	char *res_path = app_get_resource_path();
	if (res_path) {
		snprintf(file_path_out, file_path_max, "%s%s", res_path, file_in);
		free(res_path);
	}
}

/*
 * @brief: Get image path
 * @param[part_name]: Part name to which you want to set
 */
char *data_get_image(const char *part_name)
{
	/*
	 * You can use this function to retrieve data.
	 */
	char *file_path = NULL;
	char full_path[PATH_MAX] = { 0, };

	if (!strcmp("sw.icon.vol", part_name)) {
		file_path = "images/Controller/music_top_button_icon_volume.png";
	} else if (!strcmp("sw.progressbar.bg", part_name)) {
		file_path = "images/Controller/b_music_progress_bg.png";
	} else if (!strcmp("sw.icon.play", part_name)) {
		file_path = "images/Controller/music_controller_btn_play.png";
	} else if (!strcmp("sw.icon.prev", part_name)) {
		file_path = "images/Controller/music_controller_btn_prev.png";
	} else if (!strcmp("sw.icon.next", part_name)) {
		file_path = "images/Controller/music_controller_btn_next.png";
	} else {
		dlog_print(DLOG_ERROR, LOG_TAG, "failed to get image.");
		return NULL;
	}

	data_get_resource_path(file_path, full_path, (int) PATH_MAX);

	return strdup(full_path);
}

/*
 * @brief: Get text data
 * @param[part_name]: Part name to which you want to set
 */
char *data_get_text(const char *part_name)
{
	/*
	 * You can use this function to retrieve data.
	 */
	char *ret = NULL;

	if (!strcmp("sw.title", part_name)) {
		ret = strdup("Over the horizon");
	} else if (!strcmp("widget.artist", part_name)) {
		ret = strdup("Samsung");
	} else {
		dlog_print(DLOG_ERROR, LOG_TAG, "failed to get text.");
		return NULL;
	}

	return ret;
}

/*
 * @brief: Get album title
 */
char *data_get_album_title(void)
{
	return strdup("Over the horizon");
}

/*
 * @brief: Get album artist
 */
char *data_get_album_artist(void)
{
	return strdup("Samsung");
}

/*
 * @brief: Get album art
 */
char *data_get_album_art(void)
{
	char full_path[PATH_MAX] = { 0, };
	data_get_resource_path("images/bg.png", full_path, (int) PATH_MAX);

	return strdup(full_path);
}

/*
 * @brief: Get device icon image
 * @param[device]: Device type to display
 */
char *data_get_device_image(device_info_e device)
{
	char *file_path = NULL;
	char full_path[PATH_MAX] = { 0, };

	if (device == DEVICE_INFO_GEAR) {
		file_path = "images/Controller/music_gear.png";
	} else {
		file_path = "images/Controller/music_device.png";
	}

	data_get_resource_path(file_path, full_path, (int) PATH_MAX);

	return strdup(full_path);
}
